@@ -386,4 +386,92 @@ def badge(ax='ax', img='none', alpha=1, zorder=99):
     alf = alpha
     import matplotlib.image as image
     im = image.imread(logo)
-    ax.imshow(im, alpha=alf, aspect='auto', extent=(57, 93, 15, 55), zorder=z)
\ No newline at end of file
+    ax.imshow(im, alpha=alf, aspect='auto', extent=(57, 93, 15, 55), zorder=z)
+
+def zones(data, ax= 'ax', alpha=0.5, paint1 = '#0384fc', paint2 = '#FF4F3F', legend=False):
+    import matplotlib.pyplot as plt
+    from matplotlib.patches import Rectangle
+    import matplotlib.patheffects as path_effects
+    
+    col1 = '#0384fc'
+    col2 = '#FF4F3F'
+
+    ax=ax
+
+    data=data
+
+    col1 = paint1
+    col2 = paint2
+
+    edge = 'black'
+
+    alpha=alpha
+    colors = [col1, col2]
+
+    if len(data) != 48:
+        print('Error, length of data is not equal to 48')
+
+    if len(data) == 48:
+        ax.add_patch(Rectangle((0, 0), 11, 15, fc = colors[(data[0])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 0), 11, 15, fc = colors[(data[1])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 0), 18, 15, fc = colors[(data[2])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 0), 10, 15, fc = colors[(data[3])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 0), 10, 15, fc = colors[(data[4])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 0), 18, 15, fc = colors[(data[5])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 0), 11, 15, fc = colors[(data[6])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 0), 11, 15, fc = colors[(data[7])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+        ax.add_patch(Rectangle((0, 15), 11, 10, fc = colors[(data[8])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 15), 11, 10, fc = colors[(data[9])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 15), 18, 10, fc = colors[(data[10])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 15), 10, 10, fc = colors[(data[11])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 15), 10, 10, fc = colors[(data[12])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 15), 18, 10, fc = colors[(data[13])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 15), 11, 10, fc = colors[(data[14])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 15), 11, 10, fc = colors[(data[15])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+        ax.add_patch(Rectangle((0, 25), 11, 10, fc = colors[(data[16])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 25), 11, 10, fc = colors[(data[17])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 25), 18, 10, fc = colors[(data[18])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 25), 10, 10, fc = colors[(data[19])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 25), 10, 10, fc = colors[(data[20])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 25), 18, 10, fc = colors[(data[21])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 25), 11, 10, fc = colors[(data[22])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 25), 11, 10, fc = colors[(data[23])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+        ax.add_patch(Rectangle((0, 35), 11, 10, fc = colors[(data[24])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 35), 11, 10, fc = colors[(data[25])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 35), 18, 10, fc = colors[(data[26])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 35), 10, 10, fc = colors[(data[27])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 35), 10, 10, fc = colors[(data[28])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 35), 18, 10, fc = colors[(data[29])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 35), 11, 10, fc = colors[(data[30])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 35), 11, 10, fc = colors[(data[31])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+        ax.add_patch(Rectangle((0, 45), 11, 10, fc = colors[(data[32])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 45), 11, 10, fc = colors[(data[33])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 45), 18, 10, fc = colors[(data[34])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 45), 10, 10, fc = colors[(data[35])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 45), 10, 10, fc = colors[(data[36])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 45), 18, 10, fc = colors[(data[37])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 45), 11, 10, fc = colors[(data[38])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 45), 11, 10, fc = colors[(data[39])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+        ax.add_patch(Rectangle((0, 55), 11, 15, fc = colors[(data[40])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((11, 55), 11, 15, fc = colors[(data[41])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((22, 55), 18, 15, fc = colors[(data[42])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((40, 55), 10, 15, fc = colors[(data[43])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((50, 55), 10, 15, fc = colors[(data[44])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((60, 55), 18, 15, fc = colors[(data[45])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((78, 55), 11, 15, fc = colors[(data[46])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+        ax.add_patch(Rectangle((89, 55), 11, 15, fc = colors[(data[47])], fill=True, edgecolor=edge, linewidth=0.25, alpha=alpha, zorder=0))
+
+
+        if legend == True:
+            import matplotlib.font_manager as font_manager
+            font = font_manager.FontProperties(family='Serif', style='normal', size=16)
+
+            plt.plot((1, 5), (1, 5), zorder= -10, linewidth = 5, label='Team', color=col1)
+            plt.plot((1, 5), (1, 5), zorder= -10, linewidth = 5, color=col2, label='Opponent')
+
+            ax.legend(loc='lower center', prop=font, ncol=2, borderaxespad = -2, columnspacing = 1, fontsize='x-large', labelcolor='white', facecolor = 'Black', shadow = False, framealpha = 0)
\ No newline at end of file
